@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2023 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration;
 
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -13,9 +13,7 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.time.Duration;
 import java.time.Instant;
-import java.util.Locale;
-import java.util.Optional;
-import java.util.Properties;
+import java.util.*;
 import org.junit.jupiter.api.*;
 import org.junit.jupiter.api.extension.*;
 import org.junit.jupiter.api.function.Executable;
@@ -63,6 +61,33 @@ public class Common {
                   "jdbc:mariadb://%s:%s/%s?user=%s&password=%s%s",
                   hostname, port, database, user, password, defaultOther);
 
+      String srv = System.getenv("srv");
+      String version = System.getenv("v");
+      double versionInt = 0;
+      try {
+        versionInt = Double.parseDouble(version);
+      } catch (NumberFormatException | NullPointerException e) {
+        // eat
+      }
+      try (Connection c =
+          (Connection) DriverManager.getConnection(mDefUrl + "&allowPublicKeyRetrieval=true")) {
+        DatabaseMetaData meta = c.getMetaData();
+        if ("MySQL".equals(meta.getDatabaseProductName())
+            && meta.getDatabaseProductVersion().substring(0, 3).compareTo("8.4") >= 0) {
+          // choose to use allowPublicKeyRetrieval=true for testing
+          Statement stmt = c.createStatement();
+          ResultSet rs =
+              stmt.executeQuery("SHOW STATUS LIKE 'Caching_sha2_password_rsa_public_key'");
+          if (rs.next()) {
+            mDefUrl += "&serverRsaPublicKeyFile=" + rs.getString(2);
+          }
+          // mDefUrl += "&allowPublicKeyRetrieval=true";
+        }
+      } catch (SQLException e) {
+        // eat
+        e.printStackTrace();
+      }
+
     } catch (IOException io) {
       io.printStackTrace();
     }
@@ -103,6 +128,10 @@ public class Common {
     return sharedConn.getContext().hasClientCapability(capability);
   }
 
+  public static boolean srvHasCapability(long capability) {
+    return sharedConn.getContext().hasServerCapability(capability);
+  }
+
   public static boolean runLongTest() {
     String runLongTest = System.getenv("RUN_LONG_TEST");
     if (runLongTest != null) {
@@ -196,9 +225,13 @@ public class Common {
   public static Connection createCon(String option, Integer sslPort) throws SQLException {
     Configuration conf = Configuration.parse(mDefUrl + "&" + option);
     if (sslPort != null) {
-      for (HostAddress hostAddress : conf.addresses()) {
-        hostAddress.port = sslPort;
+      Configuration.Builder builder = conf.toBuilder();
+      List<HostAddress> newAddresses = new ArrayList<>();
+      for (HostAddress host : conf.addresses()) {
+        newAddresses.add(host.withPort(sslPort));
       }
+      builder.addresses(newAddresses);
+      return Driver.connect(builder.build());
     }
     return Driver.connect(conf);
   }
@@ -207,9 +240,13 @@ public class Common {
     Configuration conf =
         Configuration.parse(mDefUrl.substring(0, mDefUrl.indexOf("?")) + "?" + option);
     if (sslPort != null) {
-      for (HostAddress hostAddress : conf.addresses()) {
-        hostAddress.port = sslPort;
+      Configuration.Builder builder = conf.toBuilder();
+      List<HostAddress> newAddresses = new ArrayList<>();
+      for (HostAddress host : conf.addresses()) {
+        newAddresses.add(host.withPort(sslPort));
       }
+      builder.addresses(newAddresses);
+      return Driver.connect(builder.build());
     }
     return Driver.connect(conf);
   }
@@ -236,7 +273,10 @@ public class Common {
       throw new SQLException("proxy error", i);
     }
 
-    String url = mDefUrl.replaceAll("//([^/]*)/", "//localhost:" + proxy.getLocalPort() + "/");
+    String url =
+        mDefUrl.replaceAll(
+            "//(" + hostname + "|" + hostname + ":" + port + ")/",
+            "//localhost:" + proxy.getLocalPort() + "/");
     if (mode != HaMode.NONE) {
       url =
           url.replaceAll(
@@ -253,6 +293,41 @@ public class Common {
     return System.getProperty("os.name").toLowerCase().contains("win");
   }
 
+  public int getJavaVersion() {
+    String version = System.getProperty("java.version");
+    if (version.startsWith("1.")) {
+      version = version.substring(2, 3);
+    } else {
+      int dot = version.indexOf(".");
+      if (dot != -1) {
+        version = version.substring(0, dot);
+      }
+    }
+    return Integer.parseInt(version);
+  }
+
+  public static int getMaxScaleVersion() throws SQLException {
+    int version = 0;
+    if ("maxscale".equals(System.getenv("srv"))) {
+      java.sql.Statement st = sharedConn.createStatement();
+      /**
+       * The test system must either create the maxscale_version() function that returns the
+       * MaxScale version as an integer or MaxScale must be configured with a regexfilter that
+       * replaces the SQL with something that returns it as a constant.
+       *
+       * <pre>[InjectVersion]
+       * type=filter
+       * module=regexfilter
+       * match=SELECT maxscale_version()
+       * replace=SELECT 230800</pre>
+       */
+      ResultSet rs = st.executeQuery("SELECT maxscale_version()");
+      assertTrue(rs.next());
+      version = rs.getInt(1);
+    }
+    return version;
+  }
+
   public void cancelForVersion(int major, int minor) {
     String dbVersion = sharedConn.getMetaData().getDatabaseProductVersion();
     Assumptions.assumeFalse(dbVersion.startsWith(major + "." + minor));
