@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2024 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration;
 
 import static org.junit.jupiter.api.Assertions.*;
@@ -16,6 +16,7 @@ import org.junit.jupiter.api.*;
 import org.mariadb.jdbc.*;
 import org.mariadb.jdbc.integration.util.SocketFactoryBasicTest;
 import org.mariadb.jdbc.integration.util.SocketFactoryTest;
+import org.mariadb.jdbc.util.constants.Capabilities;
 
 @DisplayName("Connection Test")
 public class ConnectionTest extends Common {
@@ -765,7 +766,7 @@ public class ConnectionTest extends Common {
       // already existing
     }
     stmt.execute(
-        "GRANT SELECT on " + sharedConn.getCatalog() + ".* to verificationEd25519AuthPlugin");
+        "GRANT SELECT on " + sharedConn.getCatalog() + ".* to verificationEd25519AuthPlugin@'%'");
 
     try (Connection connection =
         createCon("user=verificationEd25519AuthPlugin&password=MySup8%rPassw@ord")) {
@@ -1243,7 +1244,7 @@ public class ConnectionTest extends Common {
     // ensure connecting without DB
     String connStr =
         String.format(
-            "jdbc:mariadb://%s:%s/?user=%s&password=%s&%s&createDatabaseIfNotExist",
+            "jdbc:mariadb://%s:%s/?user=%s&password=%s&%s&createDatabaseIfNotExist&allowPublicKeyRetrieval=true",
             hostname, port, user, password, defaultOther);
     try (Connection con = DriverManager.getConnection(connStr)) {
       con.createStatement().executeQuery("SELECT 1");
@@ -1252,7 +1253,7 @@ public class ConnectionTest extends Common {
     String nonExistentDatabase = "bla`f`l";
     connStr =
         String.format(
-            "jdbc:mariadb://%s:%s/%s?user=%s&password=%s&%s&createDatabaseIfNotExist",
+            "jdbc:mariadb://%s:%s/%s?user=%s&password=%s&%s&createDatabaseIfNotExist&allowPublicKeyRetrieval=true",
             hostname, port, nonExistentDatabase, user, password, defaultOther);
     try (Connection con = DriverManager.getConnection(connStr)) {
       ResultSet rs = con.createStatement().executeQuery("select DATABASE()");
@@ -1263,7 +1264,7 @@ public class ConnectionTest extends Common {
     nonExistentDatabase = "bla`f`l0";
     connStr =
         String.format(
-            "jdbc:mariadb:replication://%s:%s,%s:%s/%s?user=%s&password=%s&%s&createDatabaseIfNotExist",
+            "jdbc:mariadb:replication://%s:%s,%s:%s/%s?user=%s&password=%s&%s&createDatabaseIfNotExist&allowPublicKeyRetrieval=true",
             hostname, port, hostname, port, nonExistentDatabase, user, password, defaultOther);
     try (Connection con = DriverManager.getConnection(connStr)) {
       ResultSet rs = con.createStatement().executeQuery("select DATABASE()");
@@ -1434,4 +1435,74 @@ public class ConnectionTest extends Common {
       }
     }
   }
+
+  @Test
+  public void expiredPasswordTest() throws SQLException, InterruptedException {
+    Assumptions.assumeTrue(srvHasCapability(Capabilities.CLIENT_CAN_HANDLE_EXPIRED_PASSWORDS));
+    boolean forced = false;
+    Statement stmt = sharedConn.createStatement();
+    try {
+      stmt.execute("DROP USER IF EXISTS 'expired_pwd_user'@'%'");
+      stmt.execute("CREATE USER 'expired_pwd_user'@'%' IDENTIFIED by '!Passw0rd3Works'");
+      stmt.execute("GRANT all on *.* to 'expired_pwd_user'");
+
+      String connStr =
+          String.format(
+              "jdbc:mariadb://%s:%s/%s?user=%s&password=%s&%s&allowPublicKeyRetrieval=true",
+              hostname, port, database, "expired_pwd_user", "!Passw0rd3Works", defaultOther);
+
+      stmt.execute("ALTER USER 'expired_pwd_user'@'%' PASSWORD EXPIRE");
+      stmt.execute("FLUSH PRIVILEGES");
+      if (isMariaDBServer()) {
+        // force
+        try {
+          ResultSet rs = stmt.executeQuery("select @@global.disconnect_on_expired_password");
+          rs.next();
+          if (rs.getBoolean(1) != true) {
+            stmt.execute("set @@global.disconnect_on_expired_password=true");
+            forced = true;
+          }
+        } catch (SQLException e) {
+          // eat
+          e.printStackTrace();
+        }
+      }
+      assertThrows(SQLException.class, () -> DriverManager.getConnection(connStr));
+
+      try (Connection con =
+          DriverManager.getConnection(connStr + "&disconnectOnExpiredPasswords=false")) {
+        assertThrows(SQLException.class, () -> con.createStatement().execute("SELECT 1"));
+      }
+      try (Connection con =
+          DriverManager.getConnection(
+              connStr + "&disconnectOnExpiredPasswords=false&initSql=SELECT 1")) {
+        assertThrows(SQLException.class, () -> con.createStatement().execute("SELECT 1"));
+      }
+
+    } finally {
+      stmt.execute("DROP USER IF EXISTS 'expired_pwd_user'");
+      if (forced) stmt.execute("set @@global.disconnect_on_expired_password=false");
+    }
+  }
+
+  @Test
+  public void isClosed() throws SQLException {
+    Connection con = DriverManager.getConnection(mDefUrl);
+    Statement stmt = con.createStatement();
+    PreparedStatement preparedStatement = con.prepareStatement("SELECT ?");
+    assertFalse(stmt.isClosed());
+    assertFalse(preparedStatement.isClosed());
+
+    stmt.execute("SELECT 1");
+    preparedStatement.setInt(1, 1);
+    preparedStatement.execute();
+
+    assertFalse(stmt.isClosed());
+    assertFalse(preparedStatement.isClosed());
+
+    con.close();
+
+    assertTrue(stmt.isClosed());
+    assertTrue(preparedStatement.isClosed());
+  }
 }
