@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2024 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration;
 
 import static org.junit.jupiter.api.Assertions.*;
@@ -494,11 +494,11 @@ public class PreparedStatementParametersTest extends Common {
     Statement stmt = con.createStatement();
     stmt.execute("START TRANSACTION");
     try (PreparedStatement preparedStatement =
-        con.prepareStatement("INSERT INTO " + table + " VALUES (?)")) {
+        con.prepareStatement(String.format("INSERT INTO %s VALUES (?)", table))) {
       consumer.accept(preparedStatement);
       preparedStatement.execute();
     }
-    ResultSet rs = stmt.executeQuery("SELECT * FROM " + table);
+    ResultSet rs = stmt.executeQuery(String.format("SELECT * FROM %s", table));
     assertTrue(rs.next());
     con.rollback();
     check.accept(rs);
