@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2023 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration;
 
 import java.io.File;
@@ -219,7 +219,7 @@ public class Sha256AuthenticationTest extends Common {
 
     Common.assertThrowsContains(
         SQLException.class,
-        () -> createCon("user=cachingSha256User&password=!Passw0rd3Works"),
+        () -> createCon("user=cachingSha256User&password=!Passw0rd3Works&serverRsaPublicKeyFile="),
         "RSA public key is not available client side");
   }
 }
