@@ -1,17 +1,18 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2024 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration;
 
 import static org.junit.jupiter.api.Assertions.*;
 
 import java.io.*;
 import java.nio.file.Paths;
+import java.security.KeyStore;
 import java.security.NoSuchAlgorithmException;
+import java.security.cert.Certificate;
+import java.security.cert.CertificateFactory;
 import java.sql.*;
-import java.util.Arrays;
-import java.util.List;
-import java.util.Locale;
+import java.util.*;
 import javax.net.ssl.SSLContext;
 import org.junit.jupiter.api.*;
 import org.mariadb.jdbc.*;
@@ -103,6 +104,18 @@ public class SslTest extends Common {
     return serverCertificatePath;
   }
 
+  public static String retrieveCaCertificatePath() throws Exception {
+    String serverCertificatePath = checkFileExists(System.getProperty("serverCertificatePath"));
+    if (serverCertificatePath == null) {
+      serverCertificatePath = checkFileExists(System.getenv("TEST_DB_SERVER_CA_CERT"));
+    }
+
+    if (serverCertificatePath == null) {
+      serverCertificatePath = checkFileExists("../../ssl/ca.crt");
+    }
+    return serverCertificatePath;
+  }
+
   private static String checkFileExists(String path) throws IOException {
     if (path == null) return null;
     File f = new File(path);
@@ -152,11 +165,7 @@ public class SslTest extends Common {
   public void mandatoryEphemeralSsl() throws SQLException {
     Assumptions.assumeTrue(
         !"maxscale".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
-    Assumptions.assumeTrue(
-        isMariaDBServer()
-            && minVersion(11, 4, 1)
-            && !"mariadb-es".equals(System.getenv("srv"))
-            && !"mariadb-es-test".equals(System.getenv("srv")));
+    Assumptions.assumeTrue(isMariaDBServer() && minVersion(11, 4, 1));
     try (Connection con = createCon(baseOptions + "&sslMode=verify-ca", sslPort)) {
       assertNotNull(getSslVersion(con));
     }
@@ -174,11 +183,7 @@ public class SslTest extends Common {
 
   @Test
   void ensureSslUnixSocket() throws SQLException {
-    Assumptions.assumeTrue(
-        isMariaDBServer()
-            && minVersion(11, 4, 1)
-            && !"mariadb-es".equals(System.getenv("srv"))
-            && !"mariadb-es-test".equals(System.getenv("srv")));
+    Assumptions.assumeTrue(isMariaDBServer() && minVersion(11, 4, 1));
     Assumptions.assumeTrue(
         System.getenv("local") != null
             && "1".equals(System.getenv("local"))
@@ -201,11 +206,7 @@ public class SslTest extends Common {
   public void mandatoryEphemeralSsled25519() throws SQLException {
     Assumptions.assumeTrue(
         !"maxscale".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
-    Assumptions.assumeTrue(
-        isMariaDBServer()
-            && minVersion(11, 4, 1)
-            && !"mariadb-es".equals(System.getenv("srv"))
-            && !"mariadb-es-test".equals(System.getenv("srv")));
+    Assumptions.assumeTrue(isMariaDBServer() && minVersion(11, 4, 1));
 
     Statement stmt = sharedConn.createStatement();
     try {
@@ -238,6 +239,42 @@ public class SslTest extends Common {
     stmt.execute("drop user if exists verificationEd25519AuthPlugin@'%'");
   }
 
+  @Test
+  public void mandatoryEphemeralSslParsec() throws SQLException {
+    Assumptions.assumeTrue(!"maxscale".equals(System.getenv("srv")));
+    Assumptions.assumeTrue(isMariaDBServer() && minVersion(11, 6, 1) && getJavaVersion() >= 15);
+
+    Statement stmt = sharedConn.createStatement();
+    try {
+      stmt.execute("INSTALL SONAME 'auth_parsec'");
+    } catch (SQLException sqle) {
+      Assumptions.assumeTrue(false, "server doesn't have auth_parsec plugin, cancelling test");
+    }
+    try {
+      stmt.execute("drop user if exists verificationParsecAuthPlugin@'%'");
+    } catch (SQLException e) {
+      // eat
+    }
+    stmt.execute(
+        "CREATE USER IF NOT EXISTS verificationParsecAuthPlugin@'%' IDENTIFIED "
+            + "VIA parsec USING PASSWORD('MySup8%rPassw@ord') REQUIRE SSL");
+    stmt.execute(
+        "GRANT SELECT ON " + sharedConn.getCatalog() + ".* TO verificationParsecAuthPlugin@'%' ");
+    try (Connection con =
+        createCon(
+            "user=verificationParsecAuthPlugin&password=MySup8%rPassw@ord&sslMode=verify-ca",
+            sslPort)) {
+      assertNotNull(getSslVersion(con));
+    }
+    try (Connection con =
+        createCon(
+            "user=verificationParsecAuthPlugin&password=MySup8%rPassw@ord&sslMode=trust",
+            sslPort)) {
+      assertNotNull(getSslVersion(con));
+    }
+    stmt.execute("drop user if exists verificationParsecAuthPlugin@'%'");
+  }
+
   @Test
   void ensureUnixSocketSsl() throws SQLException {
     Assumptions.assumeTrue(
@@ -252,7 +289,7 @@ public class SslTest extends Common {
     String path = rs.getString(2);
     String url =
         mDefUrl.replaceAll(
-            "//([^/]*)/",
+            "//(" + hostname + "|" + hostname + ":" + port + ")/",
             "//address=(localSocket="
                 + path
                 + "),address=(host="
@@ -345,14 +382,19 @@ public class SslTest extends Common {
     Assumptions.assumeTrue(System.getenv("TEST_DB_CLIENT_PKCS") != null);
 
     // without password
-    assertThrows(
-        SQLInvalidAuthorizationSpecException.class,
-        () ->
-            createCon(
-                baseMutualOptions
-                    + "&sslMode=trust&keyStore="
-                    + System.getenv("TEST_DB_CLIENT_PKCS"),
-                sslPort));
+    try {
+      assertThrows(
+          SQLInvalidAuthorizationSpecException.class,
+          () ->
+              createCon(
+                  baseMutualOptions
+                      + "&sslMode=trust&keyStore="
+                      + System.getenv("TEST_DB_CLIENT_PKCS"),
+                  sslPort));
+    } catch (Throwable e) {
+      e.printStackTrace();
+      throw e;
+    }
     // with password
     try (Connection con =
         createCon(
@@ -495,7 +537,10 @@ public class SslTest extends Common {
         throw new SQLException("proxy error", i);
       }
 
-      String url = mDefUrl.replaceAll("//([^/]*)/", "//localhost:" + proxy.getLocalPort() + "/");
+      String url =
+          mDefUrl.replaceAll(
+              "//(" + hostname + "|" + hostname + ":" + port + ")/",
+              "//localhost:" + proxy.getLocalPort() + "/");
       Common.assertThrowsContains(
           SQLException.class,
           () ->
@@ -518,10 +563,7 @@ public class SslTest extends Common {
       assertNotNull(getSslVersion(con));
     }
 
-    if (isMariaDBServer()
-        && minVersion(11, 4, 1)
-        && !"mariadb-es".equals(System.getenv("srv"))
-        && !"mariadb-es-test".equals(System.getenv("srv"))) {
+    if (isMariaDBServer() && minVersion(11, 4, 1)) {
       try (Connection conn = createBasicCon(baseOptions + "&sslMode=VERIFY_CA", sslPort)) {
         conn.isValid(1);
       }
@@ -546,6 +588,114 @@ public class SslTest extends Common {
     }
   }
 
+  @Test
+  public void trustStoreParameter() throws Throwable {
+    Assumptions.assumeTrue(!"maxscale".equals(System.getenv("srv")));
+    String serverCertPath = retrieveCertificatePath();
+    String caCertPath = retrieveCaCertificatePath();
+    Assumptions.assumeTrue(serverCertPath != null, "Canceled, server certificate not provided");
+
+    KeyStore ks = KeyStore.getInstance("jks");
+    char[] pwdArray = "myPwd0".toCharArray();
+    ks.load(null, pwdArray);
+
+    File temptrustStoreFile = File.createTempFile("newKeyStoreFileName", ".jks");
+
+    KeyStore ks2 = KeyStore.getInstance("pkcs12");
+    ks2.load(null, pwdArray);
+    File temptrustStoreFile2 = File.createTempFile("newKeyStoreFileName", ".pkcs12");
+
+    try (InputStream inStream = new File(serverCertPath).toURI().toURL().openStream()) {
+      CertificateFactory cf = CertificateFactory.getInstance("X.509");
+      Collection<? extends Certificate> serverCertList = cf.generateCertificates(inStream);
+      List<Certificate> certs = new ArrayList<>();
+      for (Iterator<? extends Certificate> iter = serverCertList.iterator(); iter.hasNext(); ) {
+        certs.add(iter.next());
+      }
+      if (caCertPath != null) {
+        try (InputStream inStream2 = new File(caCertPath).toURI().toURL().openStream()) {
+          CertificateFactory cf2 = CertificateFactory.getInstance("X.509");
+          Collection<? extends Certificate> caCertList = cf2.generateCertificates(inStream2);
+          for (Iterator<? extends Certificate> iter = caCertList.iterator(); iter.hasNext(); ) {
+            certs.add(iter.next());
+          }
+        }
+      }
+      for (Certificate cert : certs) {
+        ks.setCertificateEntry(hostname, cert);
+        ks2.setCertificateEntry(hostname, cert);
+      }
+
+      try (FileOutputStream fos = new FileOutputStream(temptrustStoreFile.getPath())) {
+        ks.store(fos, pwdArray);
+      }
+      try (FileOutputStream fos = new FileOutputStream(temptrustStoreFile2.getPath())) {
+        ks2.store(fos, pwdArray);
+      }
+    }
+
+    // certificate path, like  /path/certificate.crt
+    try (Connection con =
+        createCon(
+            baseOptions
+                + "&sslMode=VERIFY_CA&trustStore="
+                + temptrustStoreFile
+                + "&trustStoreType=jks&trustStorePassword=myPwd0",
+            sslPort)) {
+      assertNotNull(getSslVersion(con));
+    }
+
+    // with alias
+    try (Connection con =
+        createCon(
+            baseOptions
+                + "&sslMode=VERIFY_CA&trustCertificateKeystoreUrl="
+                + temptrustStoreFile
+                + "&trustCertificateKeyStoretype=jks&trustCertificateKeystorePassword=myPwd0",
+            sslPort)) {
+      assertNotNull(getSslVersion(con));
+    }
+    assertThrowsContains(
+        SQLException.class,
+        () ->
+            createCon(
+                baseOptions
+                    + "&sslMode=VERIFY_CA&trustStore="
+                    + temptrustStoreFile
+                    + "&trustStoreType=jks&trustStorePassword=wrongPwd",
+                sslPort),
+        "Failed load keyStore");
+    assertThrowsContains(
+        SQLException.class,
+        () ->
+            createCon(
+                baseOptions
+                    + "&sslMode=VERIFY_CA&trustCertificateKeystoreUrl="
+                    + temptrustStoreFile
+                    + "&trustCertificateKeyStoretype=jks&trustCertificateKeystorePassword=wrongPwd",
+                sslPort),
+        "Failed load keyStore");
+    try (Connection con =
+        createCon(
+            baseOptions
+                + "&sslMode=VERIFY_CA&trustStore="
+                + temptrustStoreFile2
+                + "&trustStoreType=pkcs12&trustStorePassword=myPwd0",
+            sslPort)) {
+      assertNotNull(getSslVersion(con));
+    }
+    assertThrowsContains(
+        SQLException.class,
+        () ->
+            createCon(
+                baseOptions
+                    + "&sslMode=VERIFY_CA&trustStore="
+                    + temptrustStoreFile2
+                    + "&trustStoreType=pkcs12&trustStorePassword=wrongPwd",
+                sslPort),
+        "Failed load keyStore");
+  }
+
   private String getServerCertificate(String serverCertPath) throws SQLException {
     try (BufferedReader br =
         new BufferedReader(new InputStreamReader(new FileInputStream(serverCertPath)))) {
