@@ -941,7 +941,7 @@ public class TinyIntCodecTest extends CommonCodecTest {
     assertEquals("java.lang.Integer", meta.getColumnClassName(1));
     assertEquals("t1alias", meta.getColumnLabel(1));
     assertEquals("t1", meta.getColumnName(1));
-    assertEquals(Types.SMALLINT, meta.getColumnType(1));
+    assertEquals(Types.TINYINT, meta.getColumnType(1));
     assertEquals(4, meta.getColumnCount());
     assertEquals(3, meta.getPrecision(1));
     assertEquals(0, meta.getScale(1));
@@ -951,6 +951,20 @@ public class TinyIntCodecTest extends CommonCodecTest {
       assertEquals(3, meta.getPrecision(1));
       assertEquals(3, meta.getColumnDisplaySize(1));
     }
+
+    try (org.mariadb.jdbc.Connection conn =
+        createCon("&resultSetMetaDataUnsignedCompatibility=true")) {
+      Statement stmt = conn.createStatement();
+      stmt.execute("START TRANSACTION"); // if MAXSCALE ensure using WRITER
+      rs =
+          stmt.executeQuery(
+              "select t1 as t1alias, t2 as t2alias, t3 as t3alias, t4 as t4alias from"
+                  + " TinyIntCodecUnsigned");
+      assertTrue(rs.next());
+      stmt.execute("COMMIT");
+      meta = rs.getMetaData();
+      assertEquals(Types.SMALLINT, meta.getColumnType(1));
+    }
   }
 
   @Test
